kenchi\.outlier\_detection\.gaussian\_distns module
===================================================

.. automodule:: kenchi.outlier_detection.gaussian_distns
    :members:
    :undoc-members:
    :show-inheritance:
